@@ -2,19 +2,24 @@
 #######################################################################
 """Product class for the Zope 3 based product package
 
-$Id: test.py 50800 2008-02-21 11:13:08Z cray $
+$Id: test.py 52356 2009-01-15 15:53:27Z cray $
 """
 __author__  = "Andrey Orlov, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 50800 $"
+__version__ = "$Revision: 52356 $"
 
                     
 
 class Test(object) :
 
+    converted = ""
+    show_source = False
+
     def getData(self,*kv,**kw) :
-        return {"text":""}
+        return {"text":"", "show_source" : self.show_source}
 
     def setData(self,d,**kw) :
-        return self.context.convert(d["text"])
+        self.converted = self.context.convert(d["text"])
+        self.show_source = d["show_source"]
+        return ""
         
